//
//  MSR_ViewController.m
//  iOS
//
//  Created by leesk on 11. 11. 9..
//  Copyright 2011. All rights reserved.
//

#import "MSR_ViewController.h"

@implementation MSR_ViewController

@synthesize ipAddressField;
@synthesize track1Field;
@synthesize track2Field;
@synthesize track3Field;

@synthesize openButton;
@synthesize closeButton;
@synthesize readMSRButton;
@synthesize cancelMSRButton;

@synthesize trackSelector; 
/*
// The designated initializer. Override to perform setup that is required before the view is loaded.
- (id)initWithNibName:(NSString *)nibNameOrNil bundle:(NSBundle *)nibBundleOrNil {
    self = [super initWithNibName:nibNameOrNil bundle:nibBundleOrNil];
    if (self) {
        // Custom initialization
    }
    return self;
}
*/

/*
// Implement loadView to create a view hierarchy programmatically, without using a nib.
- (void)loadView {
}
*/


/*
// Implement viewDidLoad to do additional setup after loading the view, typically from a nib.
- (void)viewDidLoad {
    [super viewDidLoad];
}
*/


/*
// Override to allow orientations other than the default portrait orientation.
- (BOOL)shouldAutorotateToInterfaceOrientation:(UIInterfaceOrientation)interfaceOrientation {
    // Return YES for supported orientations
    return (interfaceOrientation == UIInterfaceOrientationPortrait);
}
*/

- (void) uiToggle:(UIButton*) uiObj mode:(BOOL) mode
{
	if(mode)
	{
		[uiObj setEnabled:TRUE];
		[uiObj setTitleColor:RGB(50,79,133) forState:UIControlStateNormal];
	}
	else
	{
		[uiObj setEnabled:FALSE];
		[uiObj setTitleColor:[UIColor grayColor] forState:UIControlStateNormal];	
	}
}

- (void) setUIConnected:(BOOL) isConnected
{
	if(isConnected)
	{
		[ipAddressField setEnabled:FALSE];
		[self uiToggle:openButton mode:FALSE ];
		[self uiToggle:closeButton mode:TRUE];
		[self uiToggle:readMSRButton mode:TRUE];
		[self uiToggle:cancelMSRButton mode:FALSE];
	}
	else
	{
		[ipAddressField setEnabled:TRUE];	
		[self uiToggle:openButton mode:TRUE];
		[self uiToggle:closeButton mode:FALSE];
		[self uiToggle:readMSRButton mode:FALSE];
		[self uiToggle:cancelMSRButton mode:FALSE];
	}
}

- (void) messageBox:(NSString *) message withTitle:(NSString *) title
{
	UIAlertView * alert = [[UIAlertView alloc] initWithTitle:title message:message delegate:nil cancelButtonTitle:@"OK" otherButtonTitles:nil,nil];
	[alert show];
	[alert release];
}

- (IBAction)connectCommand:(id)sender 
{
	NSString * ip = [ipAddressField text];	
	NSLog(@"Connect call\r\n");
	long errCode = 0;
	
	if((errCode = [escp openPort:ip withPortParam:9100]) >= 0)
	{
		[self setUIConnected:TRUE];
		NSLog(@"Connection Established\r\n");
	}
	else if(errCode == -3)
	{
		[self messageBox:@"Invalid device" withTitle:@"Error"];
		NSLog(@"ERROR: Invalid device\r\n");
	}
	else
	{
		[self messageBox:@"Connection error" withTitle:@"Error"];
		NSLog(@"ERROR: Connection error %ld\r\n",errCode);
	}
}

- (IBAction) disconnectCommand: (id) sender 
{
	[escp closePort];
	NSLog(@"Disconnect call\r\n");
	[self setUIConnected:FALSE];
}


// Sample

- (IBAction) readMSRTestProc:(id) sender
{
	long retVal = 0;
	// MSR Read
	[escp registerCallback:self withSelctor:@selector(callbackMSRMethod:)];
	retVal = [escp readMSR:selectedTrack];
	if(retVal == STS_MSR_READ)
	{
		[trackSelector setEnabled:FALSE];
		[self uiToggle:readMSRButton mode:FALSE];
		[self uiToggle:cancelMSRButton mode:TRUE];
	}
	else if(retVal == STS_NORMAL) 
	{
		[self messageBox:@"Fail to change MSR mode." withTitle:@"Error"];
	}
}

- (IBAction) cancelMSRTestProc:(id) sender
{
	[escp cancelMSR];
	[trackSelector setEnabled:TRUE];
	[self uiToggle:readMSRButton mode:TRUE];
	[self uiToggle:cancelMSRButton mode:FALSE];
}


// TextField
- (IBAction) textFieldDoneEditing:(id) sender
{
	[sender resignFirstResponder];
}

- (IBAction) backgroundTab:(id) sender
{
	// NSLog(@"pressed");
	[ipAddressField resignFirstResponder];
}

/////////////////////////////////
- (void) viewDidLoad 
{
	escp = [[ESCPOSPrinter alloc] init];	
	[self setUIConnected:FALSE];
	[trackSelector addTarget:self action:@selector(trackChanged:) forControlEvents:UIControlEventValueChanged];
	[trackSelector setSelectedSegmentIndex:1];
	selectedTrack = MSR_TRACK_2;
	[ipAddressField setText:@"192.168.0.188"];
}
////////////////////////////////

- (void)didReceiveMemoryWarning {
	// Releases the view if it doesn't have a superview.
    [super didReceiveMemoryWarning];
	
	// Release any cached data, images, etc that aren't in use.
}

- (void)viewDidUnload {
	// Release any retained subviews of the main view.
	// e.g. self.myOutlet = nil;
}


- (void)dealloc 
{
	[ipAddressField release];
	[track1Field release];
	[track2Field release];
	[track3Field release];
	
	[openButton release];
	[closeButton release];
	[readMSRButton release];
	[cancelMSRButton release];
	
	[trackSelector release];
	
	[escp release];
    [super dealloc];
}

- (IBAction) trackChanged:(id)sender
{
	trackSelector = sender;
	switch([trackSelector selectedSegmentIndex])
	{
		case 0:
			selectedTrack = MSR_TRACK_1;
			break;
		case 1:
			selectedTrack = MSR_TRACK_2;
			break;
		case 2:
			selectedTrack = MSR_TRACK_12;
			break;
		case 3:
			selectedTrack = MSR_TRACK_3;
			break;
		case 4:
			selectedTrack = MSR_TRACK_23;
			break;
	}
}

- (void) parsingMSRData:(NSString *) data
{
	char FS[2] = {0x1C,0x00};
	char ETX[2] = {0x03,0x00};
	
	NSArray * allData = [data componentsSeparatedByString:[NSString stringWithUTF8String:ETX]];
	NSArray * trackToken = [[allData objectAtIndex:0] componentsSeparatedByString:[NSString stringWithUTF8String:FS]];
	
    if([trackToken count] > 1)
        [track1Field setText:[trackToken objectAtIndex:1]];
	
    if([trackToken count] > 2)
        [track2Field setText:[trackToken objectAtIndex:2]];
	
    if([trackToken count] > 3)
        [track3Field setText:[trackToken objectAtIndex:3]];
	
	// Debug
	NSLog(@"All data %lu %@",(unsigned long)[allData count],[allData objectAtIndex:0]);
	for(int i=0;i<[trackToken count];i++)
	{
		NSLog(@"Track %d [%lu] = %@",i,(unsigned long)[[trackToken objectAtIndex:i] length],[trackToken objectAtIndex:i]);
	}
}

- (void) callbackMSRMethod:(id) sender
{
	if(sender == nil)
		return;
	CallbackData * cbd = (CallbackData *) sender;
	NSLog(@"Length %d\r\n",[cbd dataLength]);
	if([cbd dataLength] > 4)
	{
		[self parsingMSRData:[[NSString alloc] initWithData:[cbd data] encoding:NSUTF8StringEncoding]];
		[self cancelMSRTestProc:nil];
		//NSLog(@"Data %@\r\n",[[NSString alloc] initWithData:[cbd data] encoding:NSUTF8StringEncoding]);
	}
}

@end
